pub async fn create_feed_document(
    configuration: &Configuration,
    body: CreateFeedDocumentSpecification
) -> Result<CreateFeedDocumentResponse, Error>
Creates a feed document for the feed type that you specify. This operation returns encryption details for encrypting the contents of the document, as well as a presigned URL for uploading the encrypted feed document contents. It also returns a feedDocumentId value that you can pass in with a subsequent call to the createFeed operation. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 0.0083 | 15 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.