Function amazon_sp_feeds::apis::feeds_api::get_feed_document
source · [−]pub async fn get_feed_document(
configuration: &Configuration,
feed_document_id: &str
) -> Result<GetFeedDocumentResponse, Error>Expand description
Returns the information required for retrieving a feed document’s contents. This includes a presigned URL for the feed document as well as the information required to decrypt the document’s contents. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 0.0222 | 10 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.